"use strict";
/*
 * Copyright (c) 2024 Huawei Device Co., Ltd.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ArkObfuscatorForTest = void 0;
const ArkObfuscator_1 = require("./ArkObfuscator");
const ApiReader_1 = require("./common/ApiReader");
const FileUtils_1 = require("./utils/FileUtils");
const PrinterUtils_1 = require("./utils/PrinterUtils");
const TransformUtil_1 = require("./utils/TransformUtil");
const NameCacheUtil_1 = require("./utils/NameCacheUtil");
const fs = __importStar(require("fs"));
const path_1 = __importDefault(require("path"));
const filterFilenameList_json_1 = __importDefault(require("./configs/test262filename/filterFilenameList.json"));
const JSON_TEXT_INDENT_LENGTH = 2;
class ArkObfuscatorForTest extends ArkObfuscator_1.ArkObfuscator {
    constructor(sourceFiles, configPath) {
        super();
        this.mSourceFiles = sourceFiles;
        this.mConfigPath = configPath;
    }
    get configPath() {
        return this.mConfigPath;
    }
    /**
     * init ArkObfuscator according to user config
     * should be called after constructor
     */
    init(config) {
        if (!config) {
            console.error('obfuscation config file is not found and no given config.');
            return false;
        }
        (0, TransformUtil_1.handleReservedConfig)(config, 'mNameObfuscation', 'mReservedProperties', 'mUniversalReservedProperties');
        (0, TransformUtil_1.handleReservedConfig)(config, 'mNameObfuscation', 'mReservedToplevelNames', 'mUniversalReservedToplevelNames');
        return super.init(config);
    }
    /**
     * Obfuscate all the source files.
     */
    obfuscateFiles() {
        var _a, _b, _c, _d;
        return __awaiter(this, void 0, void 0, function* () {
            if (!path_1.default.isAbsolute(this.mCustomProfiles.mOutputDir)) {
                this.mCustomProfiles.mOutputDir = path_1.default.join(path_1.default.dirname(this.mConfigPath), this.mCustomProfiles.mOutputDir);
            }
            if (this.mCustomProfiles.mOutputDir && !fs.existsSync(this.mCustomProfiles.mOutputDir)) {
                fs.mkdirSync(this.mCustomProfiles.mOutputDir);
            }
            (_a = ArkObfuscator_1.performancePrinter === null || ArkObfuscator_1.performancePrinter === void 0 ? void 0 : ArkObfuscator_1.performancePrinter.filesPrinter) === null || _a === void 0 ? void 0 : _a.startEvent(PrinterUtils_1.EventList.ALL_FILES_OBFUSCATION);
            (0, ApiReader_1.readProjectProperties)(this.mSourceFiles, this.mCustomProfiles);
            const propertyCachePath = path_1.default.join(this.mCustomProfiles.mOutputDir, path_1.default.basename(this.mSourceFiles[0])); // Get dir name
            this.readPropertyCache(propertyCachePath);
            // support directory and file obfuscate
            for (const sourcePath of this.mSourceFiles) {
                if (!fs.existsSync(sourcePath)) {
                    console.error(`File ${FileUtils_1.FileUtils.getFileName(sourcePath)} is not found.`);
                    return;
                }
                if (fs.lstatSync(sourcePath).isFile()) {
                    yield this.obfuscateFile(sourcePath, this.mCustomProfiles.mOutputDir);
                    continue;
                }
                const dirPrefix = FileUtils_1.FileUtils.getPrefix(sourcePath);
                yield this.obfuscateDir(sourcePath, dirPrefix);
            }
            this.producePropertyCache(propertyCachePath);
            (_b = ArkObfuscator_1.performancePrinter === null || ArkObfuscator_1.performancePrinter === void 0 ? void 0 : ArkObfuscator_1.performancePrinter.filesPrinter) === null || _b === void 0 ? void 0 : _b.endEvent(PrinterUtils_1.EventList.ALL_FILES_OBFUSCATION);
            (_c = ArkObfuscator_1.performancePrinter === null || ArkObfuscator_1.performancePrinter === void 0 ? void 0 : ArkObfuscator_1.performancePrinter.timeSumPrinter) === null || _c === void 0 ? void 0 : _c.print('Sum up time of processes');
            (_d = ArkObfuscator_1.performancePrinter === null || ArkObfuscator_1.performancePrinter === void 0 ? void 0 : ArkObfuscator_1.performancePrinter.timeSumPrinter) === null || _d === void 0 ? void 0 : _d.summarizeEventDuration();
        });
    }
    /**
     * obfuscate directory
     * @private
     */
    obfuscateDir(dirName, dirPrefix) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const currentDir = FileUtils_1.FileUtils.getPathWithoutPrefix(dirName, dirPrefix);
            let newDir = this.mCustomProfiles.mOutputDir;
            // there is no need to create directory because the directory names will be obfuscated.
            if (!((_a = this.mCustomProfiles.mRenameFileName) === null || _a === void 0 ? void 0 : _a.mEnable)) {
                newDir = path_1.default.join(this.mCustomProfiles.mOutputDir, currentDir);
                if (!fs.existsSync(newDir)) {
                    fs.mkdirSync(newDir);
                }
            }
            const fileNames = fs.readdirSync(dirName);
            for (let fileName of fileNames) {
                const filePath = path_1.default.join(dirName, fileName);
                if (fs.lstatSync(filePath).isFile()) {
                    yield this.obfuscateFile(filePath, newDir);
                    continue;
                }
                yield this.obfuscateDir(filePath, dirPrefix);
            }
        });
    }
    /**
     * Obfuscate single source file with path provided
     *
     * @param sourceFilePath single source file path
     * @param outputDir
     */
    obfuscateFile(sourceFilePath, outputDir) {
        var _a, _b, _c, _d;
        return __awaiter(this, void 0, void 0, function* () {
            const fileName = FileUtils_1.FileUtils.getFileName(sourceFilePath);
            if (this.isObfsIgnoreFile(fileName)) {
                fs.copyFileSync(sourceFilePath, path_1.default.join(outputDir, fileName));
                return;
            }
            const test262Filename = this.getPathAfterTest262SecondLevel(sourceFilePath);
            const isFileInArray = filterFilenameList_json_1.default.includes(test262Filename);
            // To skip the path where 262 test will fail.
            if (isFileInArray) {
                return;
            }
            // Add the whitelist of file name obfuscation for ut.
            if ((_a = this.mCustomProfiles.mRenameFileName) === null || _a === void 0 ? void 0 : _a.mEnable) {
                const reservedArray = this.mCustomProfiles.mRenameFileName.mReservedFileNames;
                FileUtils_1.FileUtils.collectPathReservedString(this.mConfigPath, reservedArray);
            }
            let content = FileUtils_1.FileUtils.readFile(sourceFilePath);
            this.readNameCache(sourceFilePath, outputDir);
            (_b = ArkObfuscator_1.performancePrinter === null || ArkObfuscator_1.performancePrinter === void 0 ? void 0 : ArkObfuscator_1.performancePrinter.filesPrinter) === null || _b === void 0 ? void 0 : _b.startEvent(sourceFilePath);
            const mixedInfo = yield this.obfuscate(content, sourceFilePath);
            (_c = ArkObfuscator_1.performancePrinter === null || ArkObfuscator_1.performancePrinter === void 0 ? void 0 : ArkObfuscator_1.performancePrinter.filesPrinter) === null || _c === void 0 ? void 0 : _c.endEvent(sourceFilePath, undefined, true);
            if (this.mWriteOriginalFile && mixedInfo) {
                // Write the obfuscated content directly to orignal file.
                fs.writeFileSync(sourceFilePath, mixedInfo.content);
                return;
            }
            if (outputDir && mixedInfo) {
                // the writing file is for the ut.
                const testCasesRootPath = path_1.default.join(__dirname, '../', 'test/grammar');
                let relativePath = '';
                let resultPath = '';
                if (((_d = this.mCustomProfiles.mRenameFileName) === null || _d === void 0 ? void 0 : _d.mEnable) && mixedInfo.filePath) {
                    relativePath = mixedInfo.filePath.replace(testCasesRootPath, '');
                }
                else {
                    relativePath = sourceFilePath.replace(testCasesRootPath, '');
                }
                resultPath = path_1.default.join(this.mCustomProfiles.mOutputDir, relativePath);
                fs.mkdirSync(path_1.default.dirname(resultPath), { recursive: true });
                fs.writeFileSync(resultPath, mixedInfo.content);
                if (this.mCustomProfiles.mEnableSourceMap && mixedInfo.sourceMap) {
                    fs.writeFileSync(path_1.default.join(resultPath + '.map'), JSON.stringify(mixedInfo.sourceMap, null, JSON_TEXT_INDENT_LENGTH));
                }
                if (this.mCustomProfiles.mEnableNameCache && this.mCustomProfiles.mEnableNameCache) {
                    this.produceNameCache(mixedInfo.nameCache, resultPath);
                }
            }
        });
    }
    getPathAfterTest262SecondLevel(fullPath) {
        const pathParts = fullPath.split('/');
        const dataIndex = pathParts.indexOf('test262');
        // 2: Calculate the index of the second-level directory after 'test262'
        const secondLevelIndex = dataIndex + 2;
        if (dataIndex !== -1 && secondLevelIndex < pathParts.length) {
            return pathParts.slice(secondLevelIndex).join('/');
        }
        return fullPath;
    }
    produceNameCache(namecache, resultPath) {
        const nameCachePath = resultPath + NameCacheUtil_1.NAME_CACHE_SUFFIX;
        fs.writeFileSync(nameCachePath, JSON.stringify(namecache, null, JSON_TEXT_INDENT_LENGTH));
    }
    readNameCache(sourceFile, outputDir) {
        var _a;
        if (!((_a = this.mCustomProfiles.mNameObfuscation) === null || _a === void 0 ? void 0 : _a.mEnable) || !this.mCustomProfiles.mEnableNameCache) {
            return;
        }
        const nameCachePath = path_1.default.join(outputDir, FileUtils_1.FileUtils.getFileName(sourceFile) + NameCacheUtil_1.NAME_CACHE_SUFFIX);
        const nameCache = (0, NameCacheUtil_1.readCache)(nameCachePath);
        let historyNameCache = new Map();
        let identifierCache = nameCache ? Reflect.get(nameCache, NameCacheUtil_1.IDENTIFIER_CACHE) : undefined;
        (0, NameCacheUtil_1.deleteLineInfoForNameString)(historyNameCache, identifierCache);
        ArkObfuscator_1.renameIdentifierModule.historyNameCache = historyNameCache;
    }
    producePropertyCache(outputDir) {
        if (this.mCustomProfiles.mNameObfuscation &&
            this.mCustomProfiles.mNameObfuscation.mRenameProperties &&
            this.mCustomProfiles.mEnableNameCache) {
            const propertyCachePath = path_1.default.join(outputDir, NameCacheUtil_1.PROPERTY_CACHE_FILE);
            (0, NameCacheUtil_1.writeCache)(ArkObfuscator_1.PropCollections.globalMangledTable, propertyCachePath);
        }
    }
    readPropertyCache(outputDir) {
        var _a;
        if (!((_a = this.mCustomProfiles.mNameObfuscation) === null || _a === void 0 ? void 0 : _a.mRenameProperties) || !this.mCustomProfiles.mEnableNameCache) {
            return;
        }
        const propertyCachePath = path_1.default.join(outputDir, NameCacheUtil_1.PROPERTY_CACHE_FILE);
        const propertyCache = (0, NameCacheUtil_1.readCache)(propertyCachePath);
        if (!propertyCache) {
            return;
        }
        ArkObfuscator_1.PropCollections.historyMangledTable = (0, NameCacheUtil_1.getMapFromJson)(propertyCache);
    }
}
exports.ArkObfuscatorForTest = ArkObfuscatorForTest;
//# sourceMappingURL=ArkObfuscatorForTest.js.map