import type { IOptions } from '../configs/IOptions';
export declare namespace ApiExtractor {
    enum ApiType {
        API = 1,
        COMPONENT = 2,
        PROJECT_DEPENDS = 3,
        PROJECT = 4,
        CONSTRUCTOR_PROPERTY = 5
    }
    let mPropertySet: Set<string>;
    let mLibExportNameSet: Set<string>;
    let mConstructorPropertySet: Set<string>;
    let mSystemExportSet: Set<string>;
    /**
     * traverse files of  api directory
     * @param apiPath api directory path
     * @param apiType
     * @private
     */
    const traverseApiFiles: (apiPath: string, apiType: ApiType) => void;
    /**
     * desc: parse openHarmony sdk to get api list
     * @param version version of api, e.g. version 5.0.1.0 for api 9
     * @param sdkPath sdk real path of openHarmony
     * @param isEts true for ets, false for js
     * @param outputDir: sdk api output directory
     */
    function parseOhSdk(sdkPath: string, version: string, isEts: boolean, outputDir: string): void;
    function extractStringsFromFile(filePath: string): void;
    /**
     * parse common project or file to extract exported api list
     * @return reserved api names
     */
    function parseCommonProject(projectPath: string, customProfiles: IOptions, scanningApiType: ApiType): string[];
    /**
     * parse api of third party libs like libs in node_modules
     * @param libPath
     */
    function parseThirdPartyLibs(libPath: string, scanningApiType: ApiType): {
        reservedProperties: string[];
        reservedLibExportNames: string[] | undefined;
    };
    /**
     * save api json object to file
     * @private
     */
    function writeToFile(reservedProperties: string[], outputPath: string): void;
    function isRemoteHar(filePath: string): boolean;
    function isInOhModuleFile(filePath: string): boolean;
    function isParsableFile(path: string): boolean;
    /**
     * parse common project or file to extract exported api list
     * @return reserved api names
     */
    function parseProjectSourceByPaths(projectPaths: string[], customProfiles: IOptions, scanningApiType: ApiType): string[];
    /**
     * parse api of third party libs like libs in node_modules
     * @param libPath
     */
    function parseThirdPartyLibsByPaths(libPaths: string[], scanningApiType: ApiType): {
        reservedProperties: string[];
        reservedLibExportNames: string[] | undefined;
    };
}
