"use strict";
/*
 * Copyright (c) 2023 Huawei Device Co., Ltd.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.readProjectPropertiesByCollectedPaths = exports.readProjectProperties = exports.isEnabledPropertyObfuscation = exports.needReadApiInfo = exports.initPlugin = exports.scanProjectConfig = void 0;
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const FileUtils_1 = require("../utils/FileUtils");
const ApiExtractor_1 = require("./ApiExtractor");
const ListUtil_1 = require("../utils/ListUtil");
const OhsUtil_1 = require("../utils/OhsUtil");
exports.scanProjectConfig = {};
/**
 * if rename property is not open, api read and extract can be skipped
 *
 * init plugin, read api info of openHarmony sdk and generate file of reserved name, property and string.
 * @param sdkDir absolute path like D:\\HuaweiApp\\ohsdk
 * @param outputDir
 */
function initPlugin(sdkDir, outputDir) {
    // create sdk api file if not exist
    const ohSdkPath = path_1.default.resolve(sdkDir);
    if (!ohSdkPath) {
        console.error('SDK path is not found.');
    }
    const apiVersions = [''];
    apiVersions.forEach((versionString) => {
        ApiExtractor_1.ApiExtractor.parseOhSdk(ohSdkPath, versionString, true, outputDir);
    });
}
exports.initPlugin = initPlugin;
/**
 * need read api info or not
 * @param customProfiles
 */
function needReadApiInfo(customProfiles) {
    return isEnabledPropertyObfuscation(customProfiles) || customProfiles.mExportObfuscation;
}
exports.needReadApiInfo = needReadApiInfo;
function isEnabledPropertyObfuscation(customProfiles) {
    return (customProfiles.mNameObfuscation &&
        customProfiles.mNameObfuscation.mEnable &&
        customProfiles.mNameObfuscation.mRenameProperties);
}
exports.isEnabledPropertyObfuscation = isEnabledPropertyObfuscation;
/**
 * read project reserved properties for UT
 * @param projectPaths can be dir or file
 * @param customProfiles
 */
function readProjectProperties(projectPaths, customProfiles, isOHProject) {
    var _a, _b;
    let scanningCommonType = undefined;
    let scanningLibsType = undefined;
    if (isEnabledPropertyObfuscation(customProfiles)) {
        scanningCommonType = ApiExtractor_1.ApiExtractor.ApiType.PROJECT;
        scanningLibsType = ApiExtractor_1.ApiExtractor.ApiType.PROJECT_DEPENDS;
    }
    else {
        scanningCommonType = ApiExtractor_1.ApiExtractor.ApiType.CONSTRUCTOR_PROPERTY;
        scanningLibsType = ApiExtractor_1.ApiExtractor.ApiType.CONSTRUCTOR_PROPERTY;
    }
    ApiExtractor_1.ApiExtractor.mConstructorPropertySet = new Set();
    // This call is for UT.
    initScanProjectConfig(customProfiles);
    for (const projectPath of projectPaths) {
        if (!fs_1.default.existsSync(projectPath)) {
            console.error(`File ${FileUtils_1.FileUtils.getFileName(projectPath)} is not found.`);
            return { projectAndLibsReservedProperties: [], libExportNames: [] };
        }
        OhsUtil_1.stringPropsSet.clear();
        const sourcPath = isOHProject ? path_1.default.join(projectPath, 'src', 'main') : projectPath;
        const projProperties = ApiExtractor_1.ApiExtractor.parseCommonProject(sourcPath, customProfiles, scanningCommonType);
        const libExportNamesAndReservedProps = readThirdPartyLibProperties(projectPath, scanningLibsType);
        const sdkProperties = libExportNamesAndReservedProps === null || libExportNamesAndReservedProps === void 0 ? void 0 : libExportNamesAndReservedProps.reservedProperties;
        if (isEnabledPropertyObfuscation(customProfiles)) {
            // read project code export names
            customProfiles.mNameObfuscation.mReservedProperties = ListUtil_1.ListUtil.uniqueMergeList(projProperties, customProfiles.mNameObfuscation.mReservedProperties, [...OhsUtil_1.structPropsSet]);
            // read project lib export names
            if (sdkProperties && sdkProperties.length > 0) {
                customProfiles.mNameObfuscation.mReservedProperties = ListUtil_1.ListUtil.uniqueMergeList(sdkProperties, customProfiles.mNameObfuscation.mReservedProperties);
            }
            if (exports.scanProjectConfig.mKeepStringProperty && OhsUtil_1.stringPropsSet.size > 0) {
                customProfiles.mNameObfuscation.mReservedProperties = ListUtil_1.ListUtil.uniqueMergeList([...OhsUtil_1.stringPropsSet], customProfiles.mNameObfuscation.mReservedProperties);
            }
        }
        OhsUtil_1.structPropsSet.clear();
        OhsUtil_1.stringPropsSet.clear();
        if (exports.scanProjectConfig.mExportObfuscation && (libExportNamesAndReservedProps === null || libExportNamesAndReservedProps === void 0 ? void 0 : libExportNamesAndReservedProps.reservedLibExportNames)) {
            customProfiles.mNameObfuscation.mReservedNames = ListUtil_1.ListUtil.uniqueMergeList(libExportNamesAndReservedProps.reservedLibExportNames, customProfiles.mNameObfuscation.mReservedNames);
        }
    }
    return {
        projectAndLibsReservedProperties: (_a = customProfiles.mNameObfuscation.mReservedProperties) !== null && _a !== void 0 ? _a : [],
        libExportNames: (_b = customProfiles.mNameObfuscation.mReservedNames) !== null && _b !== void 0 ? _b : []
    };
}
exports.readProjectProperties = readProjectProperties;
function initScanProjectConfig(customProfiles, isHarCompiled) {
    var _a, _b, _c;
    exports.scanProjectConfig.mPropertyObfuscation = (_a = customProfiles.mNameObfuscation) === null || _a === void 0 ? void 0 : _a.mRenameProperties;
    exports.scanProjectConfig.mKeepStringProperty = (_b = customProfiles.mNameObfuscation) === null || _b === void 0 ? void 0 : _b.mKeepStringProperty;
    exports.scanProjectConfig.mExportObfuscation = customProfiles.mExportObfuscation;
    exports.scanProjectConfig.mkeepFilesAndDependencies = (_c = customProfiles.mKeepFileSourceCode) === null || _c === void 0 ? void 0 : _c.mkeepFilesAndDependencies;
    exports.scanProjectConfig.isHarCompiled = isHarCompiled;
}
/**
 * read project reserved properties by collected paths
 * @param filesForCompilation set collection of files
 * @param customProfiles
 */
function readProjectPropertiesByCollectedPaths(filesForCompilation, customProfiles, isHarCompiled) {
    var _a, _b, _c;
    const apiType = ApiExtractor_1.ApiExtractor.ApiType;
    let scanningCommonType = undefined;
    let scanningLibsType = undefined;
    if (needReadApiInfo(customProfiles)) {
        scanningCommonType = apiType.PROJECT;
        scanningLibsType = apiType.PROJECT_DEPENDS;
    }
    else {
        scanningCommonType = apiType.CONSTRUCTOR_PROPERTY;
        scanningLibsType = apiType.CONSTRUCTOR_PROPERTY;
    }
    // The purpose of collecting constructor properties is to avoid generating the same name as the constructor property when obfuscating identifier names.
    ApiExtractor_1.ApiExtractor.mConstructorPropertySet = new Set();
    initScanProjectConfig(customProfiles, isHarCompiled);
    const sourcePaths = [];
    const remoteHarParhs = [];
    filesForCompilation.forEach(path => {
        if (ApiExtractor_1.ApiExtractor.isRemoteHar(path)) {
            remoteHarParhs.push(path);
        }
        else {
            sourcePaths.push(path);
        }
    });
    OhsUtil_1.stringPropsSet.clear();
    const projProperties = ApiExtractor_1.ApiExtractor.parseProjectSourceByPaths(sourcePaths, customProfiles, scanningCommonType);
    const libExportNamesAndReservedProps = ApiExtractor_1.ApiExtractor.parseThirdPartyLibsByPaths(remoteHarParhs, scanningLibsType);
    let sdkProperties = (_a = libExportNamesAndReservedProps === null || libExportNamesAndReservedProps === void 0 ? void 0 : libExportNamesAndReservedProps.reservedProperties) !== null && _a !== void 0 ? _a : [];
    const nameObfuscationConfig = customProfiles.mNameObfuscation;
    if (isEnabledPropertyObfuscation(customProfiles)) {
        mergeReservedProperties(nameObfuscationConfig, projProperties, sdkProperties);
    }
    OhsUtil_1.structPropsSet.clear();
    OhsUtil_1.stringPropsSet.clear();
    OhsUtil_1.enumPropsSet.clear();
    if (exports.scanProjectConfig.mExportObfuscation && (libExportNamesAndReservedProps === null || libExportNamesAndReservedProps === void 0 ? void 0 : libExportNamesAndReservedProps.reservedLibExportNames)) {
        nameObfuscationConfig.mReservedNames = ListUtil_1.ListUtil.uniqueMergeList(libExportNamesAndReservedProps.reservedLibExportNames, nameObfuscationConfig.mReservedNames);
    }
    return {
        projectAndLibsReservedProperties: (_b = nameObfuscationConfig.mReservedProperties) !== null && _b !== void 0 ? _b : [],
        libExportNames: (_c = nameObfuscationConfig.mReservedNames) !== null && _c !== void 0 ? _c : []
    };
}
exports.readProjectPropertiesByCollectedPaths = readProjectPropertiesByCollectedPaths;
function mergeReservedProperties(nameObfuscationConfig, projProperties, sdkProperties) {
    // read project code export names
    nameObfuscationConfig.mReservedProperties = ListUtil_1.ListUtil.uniqueMergeList(projProperties, nameObfuscationConfig.mReservedProperties, [...OhsUtil_1.structPropsSet]);
    // read project lib export names
    if (sdkProperties && sdkProperties.length > 0) {
        nameObfuscationConfig.mReservedProperties = ListUtil_1.ListUtil.uniqueMergeList(sdkProperties, nameObfuscationConfig.mReservedProperties);
    }
    if (exports.scanProjectConfig.mKeepStringProperty && OhsUtil_1.stringPropsSet.size > 0) {
        nameObfuscationConfig.mReservedProperties = ListUtil_1.ListUtil.uniqueMergeList([...OhsUtil_1.stringPropsSet], nameObfuscationConfig.mReservedProperties);
    }
    if (OhsUtil_1.enumPropsSet.size > 0) {
        nameObfuscationConfig.mReservedProperties = ListUtil_1.ListUtil.uniqueMergeList([...OhsUtil_1.enumPropsSet], nameObfuscationConfig.mReservedProperties);
    }
}
function readThirdPartyLibProperties(projectPath, scanningApiType) {
    if (!fs_1.default.lstatSync(projectPath).isDirectory()) {
        return undefined;
    }
    // find third party lib and extract reserved names
    const fileNames = fs_1.default.readdirSync(projectPath);
    const hasNodeModules = fileNames.includes('node_modules');
    const hasOHModules = fileNames.includes('oh_modules');
    if (!hasNodeModules && !hasOHModules) {
        return undefined;
    }
    if (hasNodeModules && hasOHModules) {
        throw new Error(`There are both node_modules and oh_modules folders in ${projectPath}`);
    }
    let filePath = '';
    if (hasNodeModules) {
        filePath = path_1.default.join(projectPath, 'node_modules');
    }
    else {
        filePath = path_1.default.join(projectPath, 'oh_modules');
    }
    return ApiExtractor_1.ApiExtractor.parseThirdPartyLibs(filePath, scanningApiType);
}
//# sourceMappingURL=ApiReader.js.map