import type { ClassDeclaration, ClassExpression, ElementAccessExpression, EnumDeclaration, InterfaceDeclaration, Modifier, ObjectLiteralExpression, PropertyName, StructDeclaration, TypeAliasDeclaration } from 'typescript';
export declare const stringPropsSet: Set<string>;
/**
 * The struct properties may be initialized in other files, but the properties in the struct definition are not obfuscated.
 * So the whitelist of struct properties is collected during the project scanning process.
 */
export declare const structPropsSet: Set<string>;
/**
 * Add enum elements into whitelist when compiling har module to avoid obfuscating enum elements
 * since enum elements in js file cannot be obfuscated properly.
 */
export declare const enumPropsSet: Set<string>;
/**
 * used to ignore user defined ui component class property name
 * @param classNode
 */
export declare function isViewPUBasedClass(classNode: ClassDeclaration): boolean;
export declare function collectPropertyNamesAndStrings(memberName: PropertyName, propertySet: Set<string>): void;
export declare function getElementAccessExpressionProperties(elementAccessExpressionNode: ElementAccessExpression, propertySet: Set<string>): void;
export declare function getTypeAliasProperties(typeAliasNode: TypeAliasDeclaration, propertySet: Set<string>): void;
/**
 * export interface interfaceName {
 *  a1: number;
 *  "a2": number;
 *  ["a3"]: number;
 * }
 */
export declare function getInterfaceProperties(interfaceNode: InterfaceDeclaration, propertySet: Set<string>): void;
export declare function isParameterPropertyModifier(modifier: Modifier): boolean;
export declare function getClassProperties(classNode: ClassDeclaration | ClassExpression | StructDeclaration, propertySet: Set<string>): void;
export declare function getEnumProperties(enumNode: EnumDeclaration, propertySet: Set<string>): void;
export declare function getObjectProperties(objNode: ObjectLiteralExpression, propertySet: Set<string>): void;
export declare function getStructProperties(structNode: StructDeclaration, propertySet: Set<string>): void;
