"use strict";
/*
 * Copyright (c) 2024 Huawei Device Co., Ltd.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TimeSumPrinter = exports.TimeTracker = exports.eventList = exports.EventIndentation = exports.EventList = void 0;
const fs = __importStar(require("fs"));
var EventList;
(function (EventList) {
    EventList["OBFUSCATION_INITIALIZATION"] = "Obfuscation initialization";
    EventList["ALL_FILES_OBFUSCATION"] = "All files obfuscation";
    EventList["CREATE_AST"] = "Create AST";
    EventList["OBFUSCATE_AST"] = "Obfuscate AST";
    EventList["VIRTUAL_CONSTRUCTOR_OBFUSCATION"] = "Virtual constructor obfuscation";
    EventList["SHORT_HAND_OBFUSCATION"] = "Shorthand obfuscation";
    EventList["REMOVE_CONSOLE"] = "Remove console";
    EventList["PROPERTY_OBFUSCATION"] = "Property obfuscation";
    EventList["IDENTIFIER_OBFUSCATION"] = "Identifier obfuscation";
    EventList["CREATE_CHECKER"] = "Create checker";
    EventList["SCOPE_ANALYZE"] = "Scope analyze";
    EventList["CREATE_OBFUSCATED_NAMES"] = "Create obfuscated names";
    EventList["OBFUSCATE_NODES"] = "Obfuscate nodes";
    EventList["FILENAME_OBFUSCATION"] = "Filename obfuscation";
    EventList["CREATE_PRINTER"] = "Create Printer";
})(EventList = exports.EventList || (exports.EventList = {}));
var EventIndentation;
(function (EventIndentation) {
    EventIndentation[EventIndentation["TWOSPACE"] = 2] = "TWOSPACE";
    EventIndentation[EventIndentation["ONESPACE"] = 1] = "ONESPACE";
    EventIndentation[EventIndentation["NOSPACE"] = 0] = "NOSPACE";
})(EventIndentation = exports.EventIndentation || (exports.EventIndentation = {}));
;
exports.eventList = new Map([
    [EventList.OBFUSCATION_INITIALIZATION, EventIndentation.NOSPACE],
    [EventList.ALL_FILES_OBFUSCATION, EventIndentation.NOSPACE],
    [EventList.CREATE_AST, EventIndentation.ONESPACE],
    [EventList.OBFUSCATE_AST, EventIndentation.ONESPACE],
    [EventList.VIRTUAL_CONSTRUCTOR_OBFUSCATION, EventIndentation.TWOSPACE],
    [EventList.SHORT_HAND_OBFUSCATION, EventIndentation.TWOSPACE],
    [EventList.REMOVE_CONSOLE, EventIndentation.TWOSPACE],
    [EventList.PROPERTY_OBFUSCATION, EventIndentation.TWOSPACE],
    [EventList.IDENTIFIER_OBFUSCATION, EventIndentation.TWOSPACE],
    [EventList.CREATE_CHECKER, EventIndentation.TWOSPACE],
    [EventList.SCOPE_ANALYZE, EventIndentation.TWOSPACE],
    [EventList.CREATE_OBFUSCATED_NAMES, EventIndentation.TWOSPACE],
    [EventList.OBFUSCATE_NODES, EventIndentation.TWOSPACE],
    [EventList.FILENAME_OBFUSCATION, EventIndentation.TWOSPACE],
    [EventList.CREATE_PRINTER, EventIndentation.ONESPACE],
]);
const MILLISECOND_TO_SECOND = 1000;
const BYTE_TO_MB = 1024 * 1024;
const SIG_FIGS = 3; // 有效数字位数
const INDENT = '    ';
class BasePrinter {
    constructor(outputPath = '') {
        this.outputPath = outputPath;
    }
    setOutputPath(outputPath) {
        this.outputPath = outputPath;
    }
    print(message) {
        if (this.outputPath && this.outputPath !== '') {
            fs.appendFileSync(`${this.outputPath}`, message + '\n');
        }
        else {
            console.log(message);
        }
    }
    outputData() {
        const eventData = this.getCurrentEventData();
        this.print(eventData);
    }
}
class TimeTracker extends BasePrinter {
    constructor() {
        super(...arguments);
        this.eventStack = new Map();
        this.filesTimeSum = 0;
        this.maxTimeUsage = 0;
        this.maxTimeFile = '';
        this.maxMemoryUsage = 0;
        this.maxMemoryFile = '';
    }
    startEvent(eventName, timeSumPrinter, currentFile) {
        this.eventStack.set(eventName, { start: Date.now(), duration: 0, startMemory: process.memoryUsage().heapUsed,
            endMemory: 0, memoryUsage: 0 });
        timeSumPrinter === null || timeSumPrinter === void 0 ? void 0 : timeSumPrinter.addEventDuration(eventName, 0);
        if (eventName === EventList.CREATE_AST) {
            this.print(currentFile);
        }
    }
    endEvent(eventName, timeSumPrinter, isFilesPrinter) {
        if (!this.eventStack.get(eventName)) {
            throw new Error(`Event "${eventName}" not started`);
        }
        const eventStartTime = this.eventStack.get(eventName).start;
        const duration = (Date.now() - eventStartTime) / MILLISECOND_TO_SECOND;
        const eventEndMemory = process.memoryUsage().heapUsed;
        const eventStartMemory = this.eventStack.get(eventName).startMemory;
        const memoryUsage = eventEndMemory - eventStartMemory;
        if (isFilesPrinter) {
            this.filesTimeSum += duration;
            if (duration > this.maxTimeUsage) {
                this.maxTimeUsage = duration;
                this.maxTimeFile = eventName;
            }
            if (eventStartMemory > this.maxMemoryUsage) {
                this.maxMemoryUsage = eventStartMemory;
                this.maxMemoryFile = eventName;
            }
            if (eventEndMemory > this.maxMemoryUsage) {
                this.maxMemoryUsage = eventEndMemory;
                this.maxMemoryFile = eventName;
            }
        }
        this.eventStack.get(eventName).duration = duration;
        this.eventStack.get(eventName).endMemory = eventEndMemory;
        this.eventStack.get(eventName).memoryUsage = memoryUsage;
        timeSumPrinter === null || timeSumPrinter === void 0 ? void 0 : timeSumPrinter.addEventDuration(eventName, duration);
        if ((eventName === EventList.ALL_FILES_OBFUSCATION)) {
            this.eventStack.get(eventName).duration = this.filesTimeSum;
            this.outputData();
            const maxTimeUsage = this.maxTimeUsage.toFixed(SIG_FIGS);
            const maxMemoryUsage = (this.maxMemoryUsage / BYTE_TO_MB).toFixed(SIG_FIGS);
            this.print(`Max time cost: ${this.maxTimeFile}: ${maxTimeUsage}s`);
            this.print(`Max memory usage: ${this.maxMemoryFile}: ${maxMemoryUsage}MB\n`);
        }
        if ((eventName === EventList.CREATE_PRINTER)) {
            this.outputData();
        }
    }
    getCurrentEventData() {
        var _a;
        let eventData = '';
        for (const eventName of this.eventStack.keys()) {
            let depth = (_a = exports.eventList.get(eventName)) !== null && _a !== void 0 ? _a : 0;
            let eventInfo = this.eventStack.get(eventName);
            const duration = eventInfo.duration;
            const startMemory = eventInfo.startMemory / BYTE_TO_MB;
            const endMemory = eventInfo.endMemory / BYTE_TO_MB;
            const memoryUsage = eventInfo.memoryUsage / BYTE_TO_MB;
            eventData += this.formatEvent(eventName, duration, startMemory, endMemory, memoryUsage, depth);
        }
        return eventData;
    }
    formatEvent(eventName, duration, startMemory, endMemory, memoryUsage, depth) {
        const indent = INDENT.repeat(depth);
        const formattedDuration = duration.toFixed(SIG_FIGS) + 's';
        const formatttedStartMemory = startMemory.toFixed(SIG_FIGS) + 'MB';
        const formatttedEndMemory = endMemory.toFixed(SIG_FIGS) + 'MB';
        const formatttedMemoryUsage = memoryUsage.toFixed(SIG_FIGS) + 'MB';
        return `${indent}${eventName}: timeCost:${formattedDuration} startMemory:${formatttedStartMemory} ` +
            `endMemory:${formatttedEndMemory} memoryUsage:${formatttedMemoryUsage}\n`;
    }
}
exports.TimeTracker = TimeTracker;
class TimeSumPrinter extends BasePrinter {
    constructor() {
        super(...arguments);
        this.eventSum = new Map();
    }
    addEventDuration(eventName, duration) {
        var _a;
        const currentValue = (_a = this.eventSum.get(eventName)) !== null && _a !== void 0 ? _a : 0;
        this.eventSum.set(eventName, currentValue + duration);
    }
    summarizeEventDuration() {
        const eventData = this.getCurrentEventData();
        this.print(eventData);
    }
    getCurrentEventData() {
        var _a;
        let eventData = '';
        for (const eventName of this.eventSum.keys()) {
            let depth = (_a = exports.eventList.get(eventName)) !== null && _a !== void 0 ? _a : 0;
            const duration = this.eventSum.get(eventName);
            eventData += this.formatEvent(eventName, duration, depth);
        }
        return eventData;
    }
    formatEvent(eventName, duration, depth) {
        const indent = INDENT.repeat(depth);
        const formattedDuration = duration.toFixed(SIG_FIGS) + 's';
        return `${indent}${eventName}: ${formattedDuration}\n`;
    }
}
exports.TimeSumPrinter = TimeSumPrinter;
//# sourceMappingURL=PrinterUtils.js.map