import type { Identifier, Node, SourceFile, StructDeclaration, TransformationContext } from 'typescript';
import type { IOptions } from '../configs/IOptions';
export interface ReservedNameInfo {
    universalReservedArray: RegExp[];
    specificReservedArray: string[];
}
/**
 * collect exist identifier names in current source file
 * @param sourceFile
 */
export declare function collectExistNames(sourceFile: SourceFile): Set<string>;
type IdentifiersAndStructs = {
    shadowIdentifiers: Identifier[];
    shadowStructs: StructDeclaration[];
};
/**
 * collect exist identifiers in current source file
 * @param sourceFile
 * @param context
 */
export declare function collectIdentifiersAndStructs(sourceFile: SourceFile, context: TransformationContext): IdentifiersAndStructs;
export declare function isCommentedNode(node: Node, sourceFile: SourceFile): boolean;
export declare function isSuperCallStatement(node: Node): boolean;
/**
 * separate wildcards from specific items.
 */
export declare function separateUniversalReservedItem(originalArray: string[]): ReservedNameInfo;
/**
 * check if the item contains '*', '?'.
 */
export declare function containWildcards(item: string): boolean;
/**
 * Convert specific characters into regular expressions.
 */
export declare function wildcardTransformer(wildcard: string, isPath?: boolean): string;
/**
 * Determine whether the original name needs to be preserved.
 */
export declare function needToBeReserved(reservedSet: Set<string>, universalArray: RegExp[], originalName: string): boolean;
/**
 * Determine whether it can match the wildcard character in the array.
 */
export declare function isMatchWildcard(wildcardArray: RegExp[], item: string): boolean;
/**
 * Separate parts of an array that contain wildcard characters.
 */
export declare function handleReservedConfig(config: IOptions, optionName: string, reservedListName: string, universalLisName: string, enableRemove?: string): void;
export {};
