"use strict";
/*
 * Copyright (c) 2023 Huawei Device Co., Ltd.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeUtils = void 0;
const typescript_1 = require("typescript");
const FileUtils_1 = require("./FileUtils");
class TypeUtils {
    /**
     * Create .d.ets, .d.ts, .ts ast from .d.ets, .d.ts, .ts content.
     * Create .ts ast from .ets, .js content
     * @param {string} sourceFilePath
     * @param {string} content - The content in sourceFilePath
     */
    static createObfSourceFile(sourceFilePath, content) {
        const pathOrExtension = FileUtils_1.FileUtils.getFileSuffix(sourceFilePath);
        const fileSuffix = pathOrExtension.ext;
        if (fileSuffix === ".js" /* Extension.JS */) {
            sourceFilePath = pathOrExtension.path + ".ts" /* Extension.TS */;
        }
        return (0, typescript_1.createSourceFile)(sourceFilePath, content, typescript_1.ScriptTarget.ES2015, true);
    }
    static tsToJs(ast) {
        const pathOrExtension = FileUtils_1.FileUtils.getFileSuffix(ast.fileName);
        const fileSuffix = ".js" /* Extension.JS */;
        const targetName = pathOrExtension.path + fileSuffix;
        ast.fileName = targetName;
    }
    static createChecker(ast) {
        const host = (0, typescript_1.createCompilerHost)({});
        const customHost = {
            getSourceFile(name, languageVersion) {
                if (name === ast.fileName) {
                    return ast;
                }
                else {
                    return host.getSourceFile(name, languageVersion);
                }
            },
            // optional
            getDefaultLibLocation: () => '',
            getDefaultLibFileName: () => '',
            writeFile: (filename, data) => {
            },
            getCurrentDirectory: () => '',
            useCaseSensitiveFileNames: host.useCaseSensitiveFileNames,
            getCanonicalFileName: host.getCanonicalFileName,
            getNewLine: host.getNewLine,
            fileExists: () => true,
            readFile: (name) => {
                return name === ast.fileName ? ast.text : host.readFile(name);
            },
            // must, read program.ts => createCompilerHost
            directoryExists: undefined,
            getEnvironmentVariable: undefined,
            getDirectories: undefined,
        };
        let option = {};
        if (ast.fileName.endsWith('.js')) {
            option.allowJs = true;
        }
        let program = (0, typescript_1.createProgram)([ast.fileName], option, customHost);
        return program.getTypeChecker();
    }
}
exports.TypeUtils = TypeUtils;
//# sourceMappingURL=TypeUtils.js.map